@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004 by Puto Moura                                      *
- *   mojo@localhost.localdomain                                            *
+ *   Copyright (C) 2008 by Paulo Moura Guedes                              *
+ *   moura@kdewebdev.org                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,49 +15,56 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
+ 
 #include "linkchecker.h"
+#include "linkstatushelper.h"
 #include "searchmanager.h"
-#include "../utils/utils.h"
-#include "../parser/htmlparser.h"
+#include "utils/utils.h"
+#include "parser/htmlparser.h"
+#include "klsconfig.h"
 
-#include <qstring.h>
-#include <qtimer.h>
+#include <QString>
+#include <QTimer>
 #include <qtextcodec.h> 
-#include <qcstring.h>
 
 #include <kio/netaccess.h>
 #include <kio/global.h>
 #include <kio/job.h>
 #include <kio/scheduler.h>
-#include <kio/slave.h>
 #include <kmimetype.h>
 #include <kapplication.h>
-#include <klocale.h>
 #include <khtml_part.h>
 #include <dom/html_misc.h>
 #include <dom/dom_node.h>
 #include <dom/dom_string.h>
-
-
-int LinkChecker::count_ = 0;
+#include <dom/dom_html.h>
 
 LinkChecker::LinkChecker(LinkStatus* linkstatus, int time_out,
-                         QObject *parent, const char *name)
-        : QObject(parent, name), search_manager_(0), 
-        linkstatus_(linkstatus), t_job_(0), time_out_(time_out), checker_(0), document_charset_(), 
+                         QObject* parent)
+        : QObject(parent), search_manager_(0),
+        linkstatus_(linkstatus), t_job_(0), time_out_(time_out), document_charset_(),
         redirection_(false), header_checked_(false), finnished_(false), 
         parsing_(false), is_charset_checked_(false), has_defined_charset_(false)
 {
+//     static int i = 0;
     Q_ASSERT(linkstatus_);
-    Q_ASSERT(!linkstatus_->checked());
+//     Q_ASSERT(!linkstatus_->checked()); // rechecks are now implemented
 
-    kdDebug(23100) << endl << ++count_ << ": " << "Checking " << linkstatus_->absoluteUrl().url() << endl;
+    kDebug(23100) << "Checking " << linkstatus_->absoluteUrl().url();
+
+//     kDebug(23100) << "LinkChecker::LinkChecker " << ++i;
 }
 
 LinkChecker::~LinkChecker()
-{}
+{
+//     static int i = 0;
+//     kDebug(23100) << "LinkChecker::~LinkChecker " << ++i;
+    
+    delete t_job_;
+    t_job_ = 0;
+}
 
 void LinkChecker::setSearchManager(SearchManager* search_manager)
 {
@@ -69,22 +76,18 @@ void LinkChecker::check()
 {
     Q_ASSERT(!finnished_);
 
-    KURL url(linkStatus()->absoluteUrl());
+    KUrl url(linkStatus()->absoluteUrl());
     Q_ASSERT(url.isValid());
 
-    if(url.hasRef())
-        checkRef();
+    if(url.hasRef()) {
+        QTimer::singleShot(0, this, SLOT(slotCheckRef()));
+    }
     else
     {
-        t_job_ = KIO::get
-                     (url, false, false);
+        t_job_ = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);        
+//         t_job_->setUiDelegate(0);
 
         t_job_->addMetaData("PropagateHttpHeader", "true"); // to have the http header
-
-        if (linkstatus_->parent()) {
-            t_job_->addMetaData("referrer", linkstatus_->parent()->absoluteUrl().prettyURL());
-        }
-
         if(search_manager_->sendIdentification())
         {
             t_job_->addMetaData("SendUserAgent", "true");
@@ -98,14 +101,12 @@ void LinkChecker::check()
                          this, SLOT(slotData(KIO::Job *, const QByteArray &)));
         QObject::connect(t_job_, SIGNAL(mimetype(KIO::Job *, const QString &)),
                          this, SLOT(slotMimetype(KIO::Job *, const QString &)));
-        QObject::connect(t_job_, SIGNAL(result(KIO::Job *)),
-                         this, SLOT(slotResult(KIO::Job *)));
-        QObject::connect(t_job_, SIGNAL(redirection(KIO::Job *, const KURL &)),
-                         this, SLOT(slotRedirection(KIO::Job *, const KURL &)));
+        QObject::connect(t_job_, SIGNAL(result(KJob *)),
+                         this, SLOT(slotResult(KJob *)));
+        QObject::connect(t_job_, SIGNAL(redirection(KIO::Job *, const KUrl &)),
+                         this, SLOT(slotRedirection(KIO::Job *, const KUrl &)));
 
-        QTimer::singleShot( time_out_ * 1000, this, SLOT(slotTimeOut()) );
-        
-        t_job_->setInteractive(false);
+        QTimer::singleShot(time_out_ * 1000, this, SLOT(slotTimeOut()));
     }
 }
 
@@ -113,22 +114,22 @@ void LinkChecker::slotTimeOut()
 {
     if(!finnished_ && !parsing_)
     {
-        kdDebug(23100) << "timeout: " << linkstatus_->absoluteUrl().url() << endl;
-        if(t_job_ && t_job_->slave())
-            kdDebug(23100) << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
-        else
-            kdDebug(23100) << endl;
-
+        //kDebug(23100) << "timeout: " << linkstatus_->absoluteUrl().url() << " - " 
+        //        << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
         
-//         Q_ASSERT(t_job_); // can happen: e.g. bad result signal
+        Q_ASSERT(t_job_);
         if(t_job_->error() != KIO::ERR_USER_CANCELED)
         {
+            if(redirection_) {
+                processRedirection(redirection_url_);
+            }
             linkstatus_->setErrorOccurred(true);
-            linkstatus_->setChecked(true);
-            linkstatus_->setError(i18n("Timeout"));
+//             linkstatus_->setChecked(true);
+            linkstatus_->setError("Timeout");
             linkstatus_->setStatus(LinkStatus::TIMEOUT);
 
             killJob();
+            kDebug(23100) << "LinkChecker::slotTimeOut - " << linkstatus_->absoluteUrl().url();
             finnish();
         }
     }
@@ -139,7 +140,7 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
     if(finnished_)
         return;
 
-//     kdDebug(23100) <<  "LinkChecker::slotMimetype:" << type << "-> " << linkstatus_->absoluteUrl().url() 
+//     kDebug(23100) <<  "LinkChecker::slotMimetype:" << type << "-> " << linkstatus_->absoluteUrl().url() 
 //             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
 
     Q_ASSERT(t_job_);
@@ -152,15 +153,15 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
     Q_ASSERT(ls);
 
     ls->setMimeType(type);
-    KURL url = ls->absoluteUrl();
+    KUrl url = ls->absoluteUrl();
 
     // we doesn't do nothing if file is http or https because we need the header
     // which is only available in the data response
     if(!t_job_->error()) // if a error happened let result() handle that
     {
-        if(ls->onlyCheckHeader())
+        if(ls->onlyCheckHeader() && !KLSConfig::showMarkupStatus())
         {
-            //kdDebug(23100) <<  "only check header: " << ls->absoluteUrl().prettyURL() << endl;
+            //kDebug(23100) <<  "only check header: " << ls->absoluteUrl().prettyUrl();
 
             // file is OK (http can have an error page though job->error() is false)
             if(!url.protocol().startsWith("http"))
@@ -169,12 +170,13 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
                 ls->setStatus(LinkStatus::SUCCESSFULL);
                 
                 killJob();                
+                kDebug(23100) << "LinkChecker::slotMimetype - " << linkstatus_->absoluteUrl().url();
                 finnish();
             }
         }
         else // !ls->onlyCheckHeader()
         {
-            //kdDebug(23100) <<  "NOT only check header: " << ls->absoluteUrl().prettyURL() << endl;
+            //kDebug(23100) <<  "NOT only check header: " << ls->absoluteUrl().prettyUrl();
 
             // file is OK (http can have an error page though job->error() is false)
             if(!url.protocol().startsWith("http")) // if not, it have to go trough slotData to get the http header
@@ -182,11 +184,12 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
                 // it's not an html page, so we don't want the file content
                 if(type != "text/html"/* && type != "text/plain"*/)
                 {
-                    //kdDebug(23100) <<  "mimetype: " << type << endl;
+                    //kDebug(23100) <<  "mimetype: " << type;
                     ls->setStatusText("OK");
                     ls->setStatus(LinkStatus::SUCCESSFULL);
                     
                     killJob();                    
+                    kDebug(23100) << "LinkChecker::slotMimetype - " << linkstatus_->absoluteUrl().url();
                     finnish();
                 }
             }
@@ -199,8 +202,8 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
     if(finnished_)
         return;
 
-    kdDebug(23100) <<  "LinkChecker::slotData -> " << linkstatus_->absoluteUrl().url() 
-            << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid()  << endl;
+//     kDebug(23100) <<  "LinkChecker::slotData -> " << linkstatus_->absoluteUrl().url() 
+//             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid()  << endl;
     
     Q_ASSERT(t_job_);
     
@@ -211,11 +214,11 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
         ls = linkstatus_;
     Q_ASSERT(ls);
 
-    KURL url = ls->absoluteUrl();
+    KUrl url = ls->absoluteUrl();
 
     if(!t_job_->error())
     {
-        if(ls->onlyCheckHeader())
+        if(ls->onlyCheckHeader() && !KLSConfig::showMarkupStatus())
         {
             Q_ASSERT(header_checked_ == false);
             // the job should have been killed in slotMimetype
@@ -232,9 +235,13 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
 
                 if(header_checked_)
                 {
+                    if(redirection_) {
+                        processRedirection(redirection_url_);
+                    }
                     killJob();
                     linkstatus_->setStatus(getHttpStatus());
-                    linkstatus_->setChecked(true);
+//                     linkstatus_->setChecked(true);
+//                     kDebug(23100) << "LinkChecker::slotData 1 - " << linkstatus_->absoluteUrl().url();
                     finnish();
                     return;
                 }
@@ -248,20 +255,32 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
                 {
                     ls->setHttpHeader(getHttpHeader(t_job_));                    
                 }
-                if(ls->mimeType() != "text/html" && header_checked_)
+                if((ls->mimeType() != "text/html" && ls->mimeType() != "application/xml" )
+                    && header_checked_)
                 {
-                    //kdDebug(23100) <<  "mimetype of " << ls->absoluteUrl().prettyURL() << ": " << ls->mimeType() << endl;
+                    kDebug(23100) <<  "mimetype of " << ls->absoluteUrl().url() << ": "
+                        << ls->mimeType();
+
                     ls->setStatus(getHttpStatus());
+                    if(redirection_) {
+                        processRedirection(redirection_url_);
+                    }
                     killJob();
+//                     kDebug(23100) << "LinkChecker::slotData 2 - " << linkstatus_->absoluteUrl().url();
                     finnish(); // if finnish is called before kill what you get is a segfault, don't know why
                     return;
                 }
                 else if(t_job_->isErrorPage() && header_checked_)
                 {
-                    //kdDebug(23100) <<  "ERROR PAGE" << endl;
+                    //kDebug(23100) <<  "ERROR PAGE";
                     ls->setIsErrorPage(true);
                     ls->setStatus(getHttpStatus());
+//                     ls->setChecked(true);
+                    if(redirection_) {
+                        processRedirection(redirection_url_);
+                    }
                     killJob();
+//                     kDebug(23100) << "LinkChecker::slotData 3 - " << linkstatus_->absoluteUrl().url();
                     finnish();
                     return;
                 }
@@ -275,11 +294,11 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
             
             QTextCodec* codec = 0;
             if(has_defined_charset_) 
-                codec = QTextCodec::codecForName(document_charset_);
+                codec = QTextCodec::codecForName(document_charset_.toLatin1());
             if(!codec)
                 codec = QTextCodec::codecForName("iso8859-1"); // default
             
-            doc_html_ += codec->toUnicode(data);
+            doc_html_.append(codec->toUnicode(data));
         }
     }
 }
@@ -303,12 +322,12 @@ void LinkChecker::findDocumentCharset(QString const& doc)
 
 // only comes here if an error happened or in case of a clean html page
 // if onlyCheckHeader is false
-void LinkChecker::slotResult(KIO::Job* /*job*/)
+void LinkChecker::slotResult(KJob* /*job*/)
 {
     if(finnished_)
         return;
 
-    kdDebug(23100) <<  "LinkChecker::slotResult -> " << linkstatus_->absoluteUrl().url()  << endl;
+    kDebug(23100) <<  "LinkChecker::slotResult -> " << linkstatus_->absoluteUrl().url();
 
     Q_ASSERT(t_job_);
     if(!t_job_)
@@ -317,7 +336,7 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
     if(redirection_) {
         if(!processRedirection(redirection_url_)) {
             t_job_ = 0;
-            linkstatus_->setChecked(true);
+//             linkstatus_->setChecked(true);
             finnish();
             return;
         }
@@ -330,9 +349,10 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
 
     if(job->error() == KIO::ERR_USER_CANCELED)
     {
-        // FIXME This can happen! If the job is non interactive...
-        kdWarning(23100) << endl << "Job killed quietly, yet signal result was emited..." << endl;
-        kdDebug(23100) << linkstatus_->toString() << endl;
+        kWarning(23100) << endl << "Job killed quietly, yet signal result was emitted...";
+        kDebug(23100) << LinkStatusHelper::toString(linkstatus_);
+
+//         kDebug(23100) << "LinkChecker::slotResult - " << linkstatus_->absoluteUrl().url();
         finnish();
         return;
     }
@@ -344,22 +364,28 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
         ls = linkstatus_;
     Q_ASSERT(ls);
 
-    if(!(!ls->onlyCheckHeader() ||
-          job->error() ||
-          !header_checked_))
-        kdWarning(23100) << ls->toString() << endl;
+//     if(!((!ls->onlyCheckHeader() || (ls->onlyCheckHeader()
+//            && KLSConfig::showMarkupStatus()))
+//         || job->error()
+//         || !header_checked_))
+//         kWarning(23100) << LinkStatusHelper::toString(ls);
 
-    Q_ASSERT(!ls->onlyCheckHeader() || job->error() || !header_checked_);
+    Q_ASSERT(
+        (!ls->onlyCheckHeader() || (ls->onlyCheckHeader() && KLSConfig::showMarkupStatus()))
+        || job->error()
+        || !header_checked_);
 
-    if(ls->isErrorPage())
-        kdWarning(23100) << "\n\n" << ls->toString() << endl << endl;
+//     if(ls->isErrorPage())
+//         kWarning(23100) << "\n\n" << LinkStatusHelper::toString(ls) << endl;
 
-    Q_ASSERT(!job->isErrorPage());
+    // This can happen, Job Error code:  111
+    // http://www.wi-fi.org/OpenSection/index.asp
+//     Q_ASSERT(!job->isErrorPage());
 
     if(job->error())
     {
-        kdDebug(23100) << "Job error: " <<  job->errorString() << endl;
-        kdDebug(23100) << "Job error code: " <<  job->error() << endl;
+        kDebug(23100) << "Job Error: " <<  job->errorString();
+        kDebug(23100) << "Job Error code: " <<  job->error();
 
         if(job->error() == KIO::ERR_IS_DIRECTORY)
         {
@@ -375,11 +401,11 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
                 ls->setStatus(LinkStatus::BROKEN);
 
             if(job->errorString().isEmpty())
-                kdWarning(23100) << "\n\nError string is empty, error = " << job->error() << "\n\n\n";
+                kWarning(23100) << "\n\nError string is empty, error = " << job->error() << "\n\n\n";
             if(job->error() != KIO::ERR_NO_CONTENT) 
                 ls->setError(job->errorString());
             else
-                ls->setError(i18n("No Content"));
+                ls->setError("No Content");
         }
     }
 
@@ -393,13 +419,13 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
         {
             if(!header_checked_)
             {
-                kdDebug(23100) <<  "\n\nheader not received... checking again...\n\n\n";
+                kDebug(23100) <<  "\n\nheader not received... checking again...\n\n\n";
                 //check again
                 check();
                 return;
             }
             Q_ASSERT(header_checked_);
-            
+
             ls->setStatus(getHttpStatus());
         }
 
@@ -408,24 +434,24 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
             ls->setDocHtml(doc_html_);
 
             parsing_ = true;
-            HtmlParser parser(doc_html_);
-
-            if(parser.hasBaseUrl())
-                ls->setBaseURI(KURL(parser.baseUrl().url()));
-            if(parser.hasTitle())
-                ls->setHtmlDocTitle(parser.title().attributeTITLE());
-            
-            ls->setChildrenNodes(parser.nodes());
+//             HtmlParser parser(doc_html_);
+// 
+//             if(parser.hasBaseUrl())
+//                 ls->setBaseURI(KUrl(parser.baseUrl().url()));
+//             if(parser.hasTitle())
+//                 ls->setHtmlDocTitle(parser.title().attributeTITLE());
+//             
+//             ls->setChildrenNodes(parser.nodes());
             parsing_ = false;
         }
     }
+//     kDebug(23100) << "LinkChecker::slotResult - " << linkstatus_->absoluteUrl().url();
     finnish();
 }
 
-
-void LinkChecker::slotRedirection (KIO::Job* /*job*/, const KURL &url)
+void LinkChecker::slotRedirection (KIO::Job* /*job*/, const KUrl &url)
 {
-    kdDebug(23100) <<  "LinkChecker::slotRedirection -> " << 
+    kDebug(23100) <<  "LinkChecker::slotRedirection -> " <<
             linkstatus_->absoluteUrl().url()  << " -> " << url.url() << endl;
 //             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
     
@@ -433,12 +459,13 @@ void LinkChecker::slotRedirection (KIO::Job* /*job*/, const KURL &url)
     redirection_url_ = url;
 }
 
-bool LinkChecker::processRedirection(KURL const& toUrl)
+bool LinkChecker::processRedirection(KUrl const& toUrl)
 {
     if(finnished_)
         return true;
 
-    kdDebug(23100) <<  "LinkChecker::processRedirection -> " << linkstatus_->absoluteUrl().url() << " -> " << toUrl.url() << endl;
+    kDebug(23100) <<  "LinkChecker::processRedirection -> " << linkstatus_->absoluteUrl().url()
+        << " -> " << toUrl.url() << endl;
 
     Q_ASSERT(t_job_);
     Q_ASSERT(linkstatus_->absoluteUrl().protocol().startsWith("http"));
@@ -491,54 +518,63 @@ void LinkChecker::finnish()
 
     if(!finnished_)
     {
-        kdDebug(23100) <<  "LinkChecker::finnish -> " << linkstatus_->absoluteUrl().url() << endl;
+        kDebug(23100) <<  "LinkChecker::finnish - " << linkstatus_->absoluteUrl().url();
 
         finnished_ = true;
 
-        if(redirection_)
+        if(redirection_) {
+            // processRedirection already called
             Q_ASSERT(linkstatus_->checked());
-        else
             linkstatus_->setChecked(true);
+        }
+        else {
+            linkstatus_->setChecked(true);
+        }
 
-        emit transactionFinished(linkstatus_, this);
+          emit transactionFinished(linkstatus_, this);
     }
 }
 
 HttpResponseHeader LinkChecker::getHttpHeader(KIO::Job* /*job*/, bool remember_check)
 {
-    //kdDebug(23100) <<  "LinkChecker::getHttpHeader -> " << linkstatus_->absoluteUrl().url() << endl;
+//     kDebug(23100) <<  "LinkChecker::getHttpHeader -> " << linkstatus_->absoluteUrl().url() << endl;
     
     Q_ASSERT(!finnished_);
     Q_ASSERT(t_job_);
 
     QString header_string = t_job_->queryMetaData("HTTP-Headers");
     //    Q_ASSERT(!header_string.isNull() && !header_string.isEmpty());
-//     kdDebug(23100) << "HTTP header: " << endl << header_string << endl;
-//     kdDebug(23100) << "Keys: " << HttpResponseHeader(header_string).keys() << endl;
-//     kdDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).contentType() << endl;
-//     kdDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).value("content-type") << endl;
+//     kDebug(23100) << "HTTP header: " << endl << header_string;
+//     kDebug(23100) << "Keys: " << HttpResponseHeader(header_string).keys();
+//     kDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).contentType();
+//     kDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).value("content-type");
 
     if(header_string.isNull() || header_string.isEmpty())
     {
         header_checked_ = false;
-        kdWarning(23100) <<  "header_string.isNull() || header_string.isEmpty(): "
-        << linkstatus_->toString()  << endl;
+        kWarning(23100) <<  "header_string.isNull() || header_string.isEmpty(): "
+            << LinkStatusHelper::toString(linkstatus_) << endl;
     }
     else if(remember_check)
         header_checked_ = true;
 
+    if(header_string == "HTTP-CACHE") {
+        return HttpResponseHeader(304);
+    }
+
     return HttpResponseHeader(header_string);
 }
 
-void LinkChecker::checkRef()
+void LinkChecker::slotCheckRef()
 {
-    KURL url(linkStatus()->absoluteUrl());
+    KUrl url(linkStatus()->absoluteUrl());
     Q_ASSERT(url.hasRef());
     
     QString ref = url.ref();
-    if(ref == "" || ref == "top") {
+    if(ref.isEmpty() || ref == "top") {
         linkstatus_->setStatusText("OK");
         linkstatus_->setStatus(LinkStatus::SUCCESSFULL);
+        kDebug(23100) << "LinkChecker::slotCheckRef - " << linkstatus_->absoluteUrl().url();
         finnish();
         return;
     }
@@ -547,40 +583,47 @@ void LinkChecker::checkRef()
     LinkStatus const* ls_parent = 0;
     int i_ref = -1;
 
-    if(linkStatus()->originalUrl().startsWith("#"))
+    if(linkStatus()->originalUrl().startsWith('#'))
         ls_parent = linkStatus()->parent();
 
     else
     {
-        i_ref = url.url().find("#");
+        i_ref = url.url().indexOf('#');
         url_base = url.url().left(i_ref);
-        //kdDebug(23100) << "url_base: " << url_base << endl;
+//         kDebug(23100) << "url_base: " << url_base;
 
         Q_ASSERT(search_manager_);
 
         ls_parent = search_manager_->linkStatus(url_base);
     }
 
-    if(ls_parent)
-        checkRef(ls_parent);
+    if(ls_parent && ls_parent->checked() && ls_parent->docHtml().isEmpty())
+          checkRef(ls_parent);
     else
     {
-        url = KURL::fromPathOrURL(url.url().left(i_ref));
+        url = KUrl(url.url().left(i_ref));
         checkRef(url);
     }
 }
 
-void LinkChecker::checkRef(KURL const& url)
+void LinkChecker::checkRef(KUrl const& url)
 {
+//     kDebug(23100) << "LinkChecker::checkRef(KUrl const& url)" << url.url();
     Q_ASSERT(search_manager_);
     
     QString url_string = url.url();
     KHTMLPart* html_part = search_manager_->htmlPart(url_string);
     if(!html_part)
     {
-        kdDebug() << "new KHTMLPart: " +  url_string << endl;
+//         kDebug(23100) << "new KHTMLPart: " +  url_string;
 
-        html_part = new KHTMLPart();
+        QWidget* w = 0;
+        html_part = new KHTMLPart(w, this);
+//         html_part = new KHTMLPart();
+        html_part->setJScriptEnabled(false);
+        html_part->setJavaEnabled(false);
+        html_part->setMetaRefreshEnabled(false);
+        html_part->setPluginsEnabled(false);
         html_part->setOnlyLocalReferences(true);
 
         QString tmpFile;
@@ -595,7 +638,7 @@ void LinkChecker::checkRef(KURL const& url)
         } 
         else 
         {
-            kdDebug(23100) <<  KIO::NetAccess::lastErrorString() << endl;
+            kError(23100) <<  KIO::NetAccess::lastErrorString() << endl;
         }
 
         search_manager_->addHtmlPart(url_string, html_part);
@@ -609,42 +652,39 @@ void LinkChecker::checkRef(KURL const& url)
     else
     {
         linkstatus_->setErrorOccurred(true);
-        linkstatus_->setError(i18n( "Link destination not found." ));
+        linkstatus_->setError("Link destination not found.");
         linkstatus_->setStatus(LinkStatus::BROKEN);
     }
 
+//     kDebug(23100) << "LinkChecker::checkRef - " << linkstatus_->absoluteUrl().url();
     finnish();
 }
 
 void LinkChecker::checkRef(LinkStatus const* linkstatus_parent)
 {
+//     kDebug(23100) << "LinkChecker::checkRef(LinkStatus const* linkstatus_paren)";
+    
     Q_ASSERT(search_manager_);
 
-    QString url_string = linkstatus_parent->absoluteUrl().url();
-    KHTMLPart* html_part = search_manager_->htmlPart(url_string);
-    if(!html_part)
-    {
-        kdDebug() << "new KHTMLPart: " +  url_string << endl;
-
-        html_part = new KHTMLPart();
-        html_part->setOnlyLocalReferences(true);
-
-        html_part->begin();
-        html_part->write(linkstatus_parent->docHtml());
-        html_part->end();
-
-        search_manager_->addHtmlPart(url_string, html_part);
+    bool found = false;
+    
+    QList<Node*> const& children_nodes = linkstatus_parent->childrenNodes();
+    for(int i = 0; i != children_nodes.size(); ++i) {
+        if(children_nodes[i]->element() == Node::A) {
+            NodeA* nodeA = static_cast<NodeA*> (children_nodes[i]);
+            if(nodeA->attributeNAME() == linkStatus()->absoluteUrl().ref()) {
+                found = true;
+            }
+        }
     }
 
-    if(hasAnchor(html_part, linkStatus()->absoluteUrl().ref()))
-    {
+    if(found) {
         linkstatus_->setStatusText("OK");
         linkstatus_->setStatus(LinkStatus::SUCCESSFULL);
     }
-    else
-    {
+    else {
         linkstatus_->setErrorOccurred(true);
-        linkstatus_->setError(i18n( "Link destination not found." ));
+        linkstatus_->setError("Link destination not found.");
         linkstatus_->setStatus(LinkStatus::BROKEN);
     }
 
@@ -673,13 +713,10 @@ bool LinkChecker::hasAnchor(KHTMLPart* html_part, QString const& anchor)
 
 void LinkChecker::killJob()
 {
-    if(!t_job_)
-        return;
-
     KIO::TransferJob* aux = t_job_;
     t_job_ = 0;
     aux->disconnect(this);
-    aux->kill(true); // quietly   
+    aux->kill(); // quietly   
 }
 
 LinkStatus::Status LinkChecker::getHttpStatus() const
