@@ -1,29 +1,33 @@
 
-/***************************************************************************
-                          xsldbgthread.c  -  basic thread support
-                             -------------------
-    begin                : Thu Dec 20 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
+#include "xsldbgthread.h"
+#include "xsldbgmsg.h"
 
 #include "xsldbg.h"
 #include "breakpoint.h"
 #include "options.h"
 
-#include "xsldbgmsg.h"
-#include "xsldbgthread.h"
-
 static void (*cleanupFuncPtr)(void) = 0;
 static int threadStatus = XSLDBG_MSG_THREAD_NOTUSED;
 static int inputStatus = XSLDBG_MSG_AWAITING_INPUT;
@@ -38,28 +42,24 @@ static notifyMessageListPtr notifyList;
 
 arrayListPtr msgList = NULL;
 
-int
-getAppReady(void)
+int getAppReady(void)
 {
     return appReady;
 }
 
-void
-setAppReady(int ready)
+void setAppReady(int ready)
 {
     appReady = ready;
 }
 
 
 /* the compiler will optimize this function to inline and to keep variable private*/
-int
-getInputStatus(void)
+int getInputStatus(void)
 {
     return inputStatus;
 }
 
-void
-setInputStatus(XsldbgMessageEnum type)
+void setInputStatus(XsldbgMessageEnum type)
 {
     switch (type) {
         case XSLDBG_MSG_AWAITING_INPUT:        /* Waiting for user input */
@@ -75,15 +75,13 @@ setInputStatus(XsldbgMessageEnum type)
 
 
 /* the compiler will optimize this function to inline and to keep variable private*/
-int
-getThreadStatus(void)
+int getThreadStatus(void)
 {
     return threadStatus;
 }
 
 /* reset the status to @p type */
-void
-setThreadStatus(XsldbgMessageEnum type)
+void setThreadStatus(XsldbgMessageEnum type)
 {
     switch (type) {
         case XSLDBG_MSG_THREAD_NOTUSED:
@@ -105,31 +103,26 @@ setThreadStatus(XsldbgMessageEnum type)
 
 
 /* Is input ready yet */
-int
-getInputReady(void)
+int getInputReady(void)
 {
     return inputReady;
 }
 
 /* set/clear flag that indicates if input is ready*/
-void
-setInputReady(int value)
+void setInputReady(int value)
 {
     inputReady = value;
 }
 
 
 
-int
-notifyListStart(XsldbgMessageEnum type)
+int notifyListStart(XsldbgMessageEnum type)
 {
     int result = 0;
 
     switch (type) {
         case XSLDBG_MSG_INTOPTION_CHANGE:
         case XSLDBG_MSG_STRINGOPTION_CHANGE:
-            msgList =
-                arrayListNew(10, (freeItemFunc) optionsParamItemFree);
             break;
 
         default:
@@ -147,8 +140,7 @@ notifyListStart(XsldbgMessageEnum type)
     return result;
 }
 
-int
-notifyListQueue(const void *data)
+int notifyListQueue(const void *data)
 {
     int result = 0;
 
@@ -160,8 +152,7 @@ notifyListQueue(const void *data)
 }
 
 
-int
-notifyListSend(void)
+int notifyListSend(void)
 {
     int result = 0;
 
